=========
Changelog
=========

0.1.0
=====

**Added:**

* CLI argument to override default templates dir
* CLI argument for file output
* Add Makefile in repo for helping in local development

**Changed:**

* Create a Class for the helper, intented to be used in code or in CLI
* Refactor name ``template_helper`` to ``pyth``

0.0.0
=====

Init version :

* Read CSV file
* Read jinja2 template file
* Transform template to output file

